==> haskell-tasty-golden-2.3.2-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-golden
version: 2.3.2
id: tasty-golden-2.3.2-DcNMToe3tsmIqoCGBzOGxh
key: tasty-golden-2.3.2-DcNMToe3tsmIqoCGBzOGxh
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka
homepage: https://github.com/feuerbach/tasty-golden
synopsis: Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.
category: Testing
abi: fd95df901356ec765837c688edae798d
exposed: True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage
hidden-modules: Test.Tasty.Golden.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-golden-2.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-golden-2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-golden-2.3.2
hs-libraries: HStasty-golden-2.3.2-DcNMToe3tsmIqoCGBzOGxh
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2
    optparse-applicative-0.14.3.0-6K67dnjFISmWjyySSwRel process-1.6.5.0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2-7U7pobVPBj2AeWtnevypzS
    temporary-1.3-2R9bhTuduqsDRv55IV8XfU
haddock-interfaces: /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock
haddock-html: /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-golden-2.3.2-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-golden
version: 2.3.2
id: tasty-golden-2.3.2-H6HhoiHUqfLBJXGwpKNvr6
key: tasty-golden-2.3.2-H6HhoiHUqfLBJXGwpKNvr6
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka
homepage: https://github.com/feuerbach/tasty-golden
synopsis: Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.
category: Testing
abi: 902db8592f70d2f93b10baa0457aac3a
exposed: True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage
hidden-modules: Test.Tasty.Golden.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-golden-2.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-golden-2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-golden-2.3.2
hs-libraries: HStasty-golden-2.3.2-H6HhoiHUqfLBJXGwpKNvr6
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 deepseq-1.4.4.0
    directory-1.3.3.0 filepath-1.4.2.1 mtl-2.2.2
    optparse-applicative-0.14.3.0-88hVANjMmYe4YgS4EkwjRh
    process-1.6.5.0 tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2-FCm8BchjBAQ8cLnSJjYG9C
    temporary-1.3-5cWlygi8YnlCS3tuKAJyz3
haddock-interfaces: /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock
haddock-html: /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
